@@ -1,13 +1,12 @@
 package WWW::Chain;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: A web request chain
-
-our $VERSION ||= '0.000';
-
+$WWW::Chain::VERSION = '0.005';
 
 use Moo;
 use MooX::Types::MooseLike::Base qw(:all);
 use Safe::Isa;
+use WWW::Chain::UA::LWP;
 
 has stash => (
 	isa => HashRef,
@@ -59,6 +58,11 @@ sub BUILDARGS {
 	};
 }
 
+sub request_with_lwp {
+  my ( $self ) = @_;
+  return WWW::Chain::UA::LWP->new->request_chain($self);
+}
+
 sub parse_chain {
 	my ( $self, @args ) = @_;
 	my $coderef;
@@ -118,7 +122,7 @@ WWW::Chain - A web request chain
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
