@@ -1,10 +1,12 @@
 package WWW::Chain::UA::LWP;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Using LWP::UserAgent to execute WWW::Chain chains
-$WWW::Chain::UA::LWP::VERSION = '0.004';
+$WWW::Chain::UA::LWP::VERSION = '0.005';
 use Moo;
 extends 'LWP::UserAgent';
 
+use HTTP::Cookies;
+
 with qw( WWW::Chain::UA );
 
 use Scalar::Util 'blessed';
@@ -14,6 +16,7 @@ sub request_chain {
 	my ( $self, $chain ) = @_;
 	die __PACKAGE__."->request_chain needs a WWW::Chain object as parameter"
 		unless ( blessed($chain) && $chain->$_isa('WWW::Chain') );
+	$self->cookie_jar({}) unless $self->cookie_jar;
 	while (!$chain->done) {
 		my @responses;
 		for (@{$chain->next_requests}) {
@@ -37,7 +40,7 @@ WWW::Chain::UA::LWP - Using LWP::UserAgent to execute WWW::Chain chains
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 AUTHOR
 
